@@ -25,10 +25,6 @@ class ScopeControllerBase:
         self.arrays = np.array([])
         self.lastArrays = 0
 
-        self.default_arrayid = "None"
-        self.default_xaxes = "None"
-        self.current_arrayid = "None"
-        self.current_xaxes = "None"
         self.default_trigger = None
         self.trigger_is_monitor = False
         self.trigger_auto_scale = False
@@ -39,7 +35,7 @@ class ScopeControllerBase:
         self.status_timer = pyqtgraph.QtCore.QTimer()
         self.status_timer.timeout.connect(self.update_status)
         self.status_timer.start(1000)
-
+        
     def set_trigger_pv(self, pvname):
         if self._win.graphicsWidget.plotting_started:
             self.notify_warning("Stop plotting first before changing trigger PV")
@@ -70,30 +66,14 @@ class ScopeControllerBase:
                                 
         except Exception as e:
             self.notify_warning("Channel {}://{} timed out. \n{}".format(proto, name, repr(e)))
-            
+
 
     def default_config(self, **kwargs):
-        """
-        Default configuration for array ID and x axes field names
-
-        :param kwargs:
-        :return:
-        """
-        self.default_arrayid = kwargs.get("arrayid", None)
-        if self.default_arrayid is None:
-            self.default_arrayid = "None"
-        else:
-            self._win.graphicsWidget.set_arrayid(self.default_arrayid)
-        self.default_xaxes = kwargs.get("xaxes", None)
-        if self.default_xaxes is None:
-            self.default_xaxes = "None"
-        else:
-            self._win.graphicsWidget.set_xaxes(self.default_xaxes)
-        self._win.graphicsWidget.set_range(**kwargs)
-
-        max_length = self.parameters.child("Acquisition").child("Buffer (Samples)").value()
-        if max_length:
-            self._win.graphicsWidget.update_buffer(int(max_length))
+        buffer_unit = kwargs.get('buffer_unit', 'Samples')
+            
+        max_length = self.parameters.child("Acquisition").child("Buffer (%s)" % buffer_unit).value()
+        if max_length and buffer_unit == 'Samples':
+            self.update_buffer_samples(int(max_length))
             
         self._win.graphicsWidget.set_binning(self.parameters.child("Display").child("Num Bins").value())
 
@@ -109,11 +89,17 @@ class ScopeControllerBase:
             self.trigger_auto_scale = self.parameters.child("Trigger").child("Autoscale Buffer").value()
         except:
             pass
+
         
-    def update_buffer(self, size):
+    def update_buffer_samples(self, size):
+        """
+        Sets number of samples in buffer
+        
+        :param size  size of buffer in number of samples
+        """
         self._win.graphicsWidget.update_buffer(size)
         self.parameters.child("Acquisition").child("Buffer (Samples)").setValue(self._win.graphicsWidget.max_length)
-
+            
     def parameter_change(self, params, changes):
         """
         
@@ -170,10 +156,6 @@ class ScopeControllerBase:
                     self._win.graphicsWidget.set_binning(data)
                 elif childName == "Display.Refresh":
                     self.set_freshrate(data)
-                elif childName == "Config.ArrayId":
-                    self.set_arrayid(data)
-                elif childName == "Config.X Axes":
-                    self.set_xaxes(data)
 
     def set_freshrate(self, value):
         """
@@ -221,30 +203,7 @@ class ScopeControllerBase:
 
         self.timer.stop()
         self.stop_trigger()
-        
-    def set_arrayid(self, value):
-        """
-        Set current field name for array id
-            
-        :param value:
-        :return:
-        """
-        if value != self.current_arrayid:
-            self.current_arrayid = value
-            self._win.graphicsWidget.current_arrayid = value
-
-    def set_xaxes(self, value):
-        """
-        Set current field name for x axes
-            
-        :param value:
-        :return:
-        """
-        if value != self.current_xaxes:
-            self.current_xaxes = value
-            self._win.graphicsWidget.current_xaxes = value
-            self.new_buffer = True
-            
+                    
     def set_trigger_mode(self, value):
         """
         Set trigger mode.
@@ -366,6 +325,6 @@ class ScopeControllerBase:
                 roundunit = 10**max(exp - precision, 0)
                 newsize = math.ceil(newsize / roundunit) * roundunit
 
-                self.update_buffer(newsize)
+                self.update_buffer_samples(newsize)
             
         
