@@ -1,11 +1,7 @@
 class ScopeConfigureBase:
     def __init__(self, params, **kwargs):
         self.params = params
-        self.default_arrayid = kwargs.get("arrayid", "None")
-        self.default_xaxes = kwargs.get("xaxes", "None")
         self.default_trigger = kwargs.get("trigger", None)
-        self.show_start = kwargs.get("show_start", False)
-
 
     def add_source_aquisition_props(self, children, section):
         """
@@ -14,33 +10,27 @@ class ScopeConfigureBase:
         """
         return children
 
-    def assemble_acquisition(self, section=None):
+    def assemble_acquisition(self, section=None, buffer_unit='Samples'):
         """
         Assemble acquisition information
 
         :param section:
         :return:
         """
-        
+
         children = []
-        buffer = None
+
+        buffer_size = None
+        try:
+            buffer_size = section["BUFFER"]
+        except:
+            pass
         
-        if section:
-            try:
-                buffer = section["BUFFER"]
-            except Exception:
-                pass
-            
         children += [
             {"name": "Freeze", "type": "bool", "value": False},
-            {"name": "Buffer (Samples)", "type": "int", "value": buffer, "siPrefix": False, 'decimals': 20}
+            {"name": "Buffer (%s)" % buffer_unit, "type": "int", "value": buffer_size, "siPrefix": False, 'decimals': 20}
         ]
 
-        children = self.add_source_acquisition_props(children, section)        
-
-        if self.show_start:
-            children.append({"name": "Start", "type": "bool", "value": False})
-
         acquisition = {"name": "Acquisition", "type":"group", "children": children}
         
         return acquisition
@@ -198,25 +188,6 @@ class ScopeConfigureBase:
               ]}
         return cfg
         
-    def assemble_config(self):
-        # Assemble extra configuration information for plotting
-        # which is ArrayId selection, and x axes
-        id_value = ["None"]
-        if self.default_arrayid != "None":
-            id_value.append(self.default_arrayid)
-        axes = ["None"]
-        if self.default_xaxes != "None":
-            axes.append(self.default_xaxes)
-
-        cfg = {"name": "Config",
-               "type": "group",
-               "children": [
-                   {"name": "ArrayId", "type": "list", "values": id_value, "value": self.default_arrayid},
-                   {"name": "X Axes", "type": "list", "values": axes, "value": self.default_xaxes},
-               ]
-               }
-        return cfg
-
     def assemble_statistics(self):
         statistics = {"name": "Statistics", "type": "group", "children": [
             {"name": "CPU", "type": "float", "value": 0, "readonly": True, "suffix": "%"},
