@@ -2,13 +2,15 @@ from .scope_config_base import ScopeConfigureBase
 
 class StripToolConfigure(ScopeConfigureBase):
     def __init__(self, params, **kwargs):
-        super().__init__(params,
-                         show_start=False,
-                         **kwargs)
+        super().__init__(params, **kwargs)
+
+    def assemble_acquisition(self, section=None):
+        acquisition = super().assemble_acquisition(section)
+        children = acquisition['children']
 
-    def add_source_acquisition_props(self, children, section):
         children.append({"name": "Sample Mode", "type":"bool", "value": True})
-        return children
+
+        return acquisition
     
     def parse(self):
         try:
@@ -21,10 +23,9 @@ class StripToolConfigure(ScopeConfigureBase):
         except KeyError:
             display = self.assemble_display()
             
-        cfg = self.assemble_config()
         statistics = self.assemble_statistics()
         # line up in order
-        paramcfg = [acquisition, display, cfg, statistics]
+        paramcfg = [acquisition, display, statistics]
 
         return paramcfg
 
